@@ -151,7 +151,7 @@ class Beats(Process):
 
         for ctr in range(iterations):
             # Randomly select our samples
-            drums_sample = self._inventory.selectRandom("Beats")
+            drums_sample = self._inventory.selectRandom("Beat")
             bass_sample = self._inventory.selectRandom("Bass")
             pads_sample = self._inventory.selectRandom("Pad")
 
